@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.9 2001/10/21 19:48:32 kapheine Exp $ */
+/* $Id: main.c,v 1.7 2001/04/28 20:32:47 kapheine Exp $ */
 
 #include <config.h>
 #include <stdio.h>
@@ -6,11 +6,7 @@
 #include <unistd.h>
 #include <string.h>
 #include <time.h>
-#ifndef HAVE_GETOPT 
-  #include "getopt.h"
-#else
-  #include <getopt.h>
-#endif
+#include <getopt.h>
 #ifdef MEMWATCH
 #include "memwatch.h"
 #endif /* MEMWATCH */
@@ -20,7 +16,7 @@
 static const char *program_name = PACKAGE;
 static const char *author = "Zachary P. Landau";
 static const char *version = VERSION;
-static const char *email = "kapheine@hypa.net";
+static const char *email = "kapheine@divineinvasion.net";
 static const char *description = "an HTTP authentication brute forcer";
 
 /* command line configurable variables */
@@ -46,9 +42,11 @@ char pathlist[120] = DEFAULT_PATH;
 char configlist[120] = DEFAULT_CONFIG;
 
 char *user_pass[2];							/* username, password */
-FILE *log;									/* log file handle */
+FILE *logfd;								/* log file handle */
 unsigned int found = 0;						/* valid auth found */
 unsigned int num_users = 0;					/* cur number of users tried */
+unsigned int no_ssl_fail = 0;
+unsigned int auth_digest = 0;
 int session_usernumber = 0; 				/* current usernumber */
 int session_function = passwords_ident;     /* current function */
 int session_count = 0;						/* current loop */
@@ -81,6 +79,8 @@ struct option long_options[] = {
 	{ "user-delay", 1, NULL, 5 },
 	{ "user-agent", 1, NULL, 'a' },
 	{ "username-file", 1, NULL, 6 },
+	{ "no-ssl-fail", 0, NULL, 7 },
+	{ "auth-digest", 0, NULL, 8 },
 	{ "verbose", 0, NULL, 'v' },
 	{ "version", 0, NULL, 'V' },
 	{ NULL }
@@ -109,6 +109,8 @@ static void help(char *name) {
 			"\t\t--password-file=FILE\tfile containing common passwords\n"
 			"\t-p,\t--path=STRING\t\tlook for pathlist STRING\n"
 			"\t-P,\t--proxy=STRING\t\tset proxy to STRING\n"
+			"\t\t--auth-digest\t\tuse auth digest method\n"
+			"\t\t--no-ssl-fail\t\tdon't fail with self signed certs\n"
 			"\t-q,\t--quiet\t\t\tdon't output to stdout\n"
 			"\t\t--user-delay=NUMBER\tdelay for # seconds between usernames\n"
 			"\t\t--username-file=FILE\tfile containing list of usernames\n"
@@ -161,6 +163,12 @@ static void initialize_main(int argc, char *argv[]) {
 			case 6:
 				strncpy(username_file, optarg, sizeof(username_file));
 				break;
+			case 7:
+				no_ssl_fail = 1;
+				break;
+			case 8:
+				auth_digest = 1;
+				break;
 			case 'a':
 				strncpy(user_agent, optarg, sizeof(user_agent));
 				break;
@@ -210,7 +218,7 @@ static void initialize_main(int argc, char *argv[]) {
 						"Copyright (C) 2000 %s\n"
 						"There is NO warranty.  You may redistribute this software\n"
 						"under the terms of the GNU General Public License.\n"
-						"For more information about these matters, see the file named COPYING\n"
+						"For more information about these matters, see the files named COPYING\n"
 						"\n"
 						"Written by %s <%s>.\n")
 						, program_name, version, author, author, email);
@@ -243,13 +251,13 @@ static void initialize_main(int argc, char *argv[]) {
 	if (save_session)
 		install_handler();
 
-	log = fopen(logfile, "w+");
-	if (!log) {
+	logfd = fopen(logfile, "w+");
+	if (!logfd) {
 		fprintf(stderr, _("initialize_data: couldn't open %s\n"), logfile);
 		exit(EXIT_FAILURE);
 	}
 	now = time(0);
-	fprintf(log, _("scan started: %s"), ctime(&now));
+	fprintf(logfd, _("scan started: %s"), ctime(&now));
 	
 }
 
@@ -258,8 +266,8 @@ static void shutdown_main(void) {
 
 	now = time(0);
 /*	printf("sats: %f\n", acs);*/
-	fprintf(log, _("scan ended: %s"), ctime(&now));
-	fclose(log);
+	fprintf(logfd, _("scan ended: %s"), ctime(&now));
+	fclose(logfd);
 }
 
 int main(int argc, char *argv[]) {
@@ -305,8 +313,8 @@ int main(int argc, char *argv[]) {
 		path = search_path(passwords_file, pathlist);
 		master_password_list = textlist(path);
 
-		/* session_usernumber starts at 0, but num_lines starts at 1 */
-		if (abs(session_count) > (num_lines-1)) {
+		/* session_count starts at 0, but num_lines starts at 1 */
+		if (abs(session_count) > (num_lines+1)) {
 			fprintf(stderr, _("main: session_count greater than num_lines\n"));
 			exit(EXIT_FAILURE);
 		}
@@ -319,7 +327,7 @@ int main(int argc, char *argv[]) {
 					if (beep)
 						printf("\007");
 				}
-				fprintf(log, _("match [%s:%s]\n"), user_pass[0], user_pass[1]);
+				fprintf(logfd, _("match [%s:%s]\n"), user_pass[0], user_pass[1]);
 				found++;
 			}
 			sleep(per_user_delay);
@@ -328,7 +336,7 @@ int main(int argc, char *argv[]) {
 			if (max_users == num_users && max_users != 0) {
 				if (!quiet)
 					printf(_("max users reached at %i\n"), num_users);
-				fprintf(log, _("max users reached at %i\n"), num_users);
+				fprintf(logfd, _("max users reached at %i\n"), num_users);
 				break;
 			}
 			num_users++;
@@ -344,11 +352,11 @@ int main(int argc, char *argv[]) {
 	if (found > 0) {
 		if (!quiet)
 			printf(_("Congratulations: %i password%s found.\n"), found, found == 1 ? "" : "s");
-		fprintf(log, _("Congratulations: %i password%s found.\n"), found, found == 1 ? "" : "s");
+		fprintf(logfd, _("Congratulations: %i password%s found.\n"), found, found == 1 ? "" : "s");
 	} else {
 		if (!quiet)
 			printf(_("No passwords found.\n"));
-		fprintf(log, _("No passwords found.\n"));
+		fprintf(logfd, _("No passwords found.\n"));
 	}
 		
 	free(user_pass[0]);
